---
name: "\U0001F41E Issues, bugs and problems"
about: Contribute a report and describe what should have happened.
title: ''
labels: ''
assignees: ''

---

<!-- Thank you for taking the time to create this issue. Your feedback is appreciated ! -->
<!-- Consider reading the documentation on https://ara.readthedocs.io/en/latest/ and joining us on Slack or IRC: https://ara.recordsansible.org/community/ -->


## What is the issue ?
<!--
  Include relevant information to help the community help you. Some examples:
  - the component that you are creating this issue about (api server, api client, web ui, ansible plugins, etc.)
  - linux distribution, version of python, version of ara and ansible
  - how is ara installed (from source, pypi, in a container, etc.) and how you are running it (database backend, wsgi server, etc.)
  - debugging logs by setting ARA_DEBUG to True and ARA_LOG_LEVEL to DEBUG
  - instructions on how to reproduce the issue
-->


## What should be happening ?

